==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/view_rozdeleni_dv_v1.php <==
<?php
/**
 * stanislav.elbl, 27.02.2015
 * Stary zpusob rozdeleni dennich vysledku
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Kalendar;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;

/**
 * @var HromadneRozdeleniDVFormular $this
 */

$datumodstr = isset($_POST['rozdelenidv_datumod']) ? $_POST['rozdelenidv_datumod'] : date('j.n.Y', $this ->editovatDatumOd);
$datumdostr = isset($_POST['rozdelenidv_datumdo']) ? $_POST['rozdelenidv_datumdo'] : date('j.n.Y', $this ->editovatDatumDo);

?>

<h1><?= TextManager::_('Rozdeleni_dennich_vysledku') ?></h1>

<form method="POST" name="rozdeleniDVform" action="?menuid=rozdelenidv&idpp=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>">
    <input type="hidden" name="ulozitRozdeleniDV" value="1" />
    <input type="hidden" name="osoba" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>" />


    <!-- hlavicka -->
    <div class="form large-form filtrRozdeleniDV">
        <div class="form-content">
            <!-- osoba a filtr datum od-do -->
            <div class="row">
                <div class="col col-3 caption required"><?= StringUtils::htmlTextConvert($this ->pp ->jmeno . ' ' . $this ->pp ->prijmeni) ?></div>

                <?php if (!$this ->readOnly) { ?>

                    <div class="col col-2 caption"><?= TextManager::_('Datum_od') ?></div>
                    <div class="col col-6">
                        <input id="rozdeleniDV_DatumOd" type='text' size='10' maxlength='10' name='rozdelenidv_datumod' value='<?= StringUtils::htmlTextConvert($datumodstr) ?>'
                               data-roncalendar-mindate="<?= date('j.n.Y', $this ->obdobi ->zacatek) ?>" data-roncalendar-maxdate="<?= date('j.n.Y', $this ->obdobi ->konec) ?>"
                               data-roncalendar-next="rozdelenidv_datumdo" />
                        <i class="showcalendar inline-glyph fa glyph-calendar"  data-roncalendar-inputname="rozdelenidv_datumod"></i>

                        &nbsp;&nbsp;&nbsp;<?= TextManager::_('Do') ?>

                        <input id="rozdeleniDV_DatumDo" type='text' size='10' maxlength='10' name='rozdelenidv_datumdo' value='<?= StringUtils::htmlTextConvert($datumdostr) ?>'
                               data-roncalendar-mindate="<?= date('j.n.Y', $this ->obdobi ->zacatek) ?>" data-roncalendar-maxdate="<?= date('j.n.Y', $this ->obdobi ->konec) ?>"
                               data-roncalendar-prev="rozdelenidv_datumod" />
                        <i class="showcalendar inline-glyph fa glyph-calendar"  data-roncalendar-inputname="rozdelenidv_datumdo"></i>

                        <?php if (RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) { ?>
                            <span class="js float-right" onclick="ronPortal.rozdeleniOsoby_DVHromadne(<?= $this ->pp ->idPP ?>)"><?= TextManager::_('Vybrat_rozdeleni') ?></span>
                        <?php } ?>

                    </div>
                <?php } else { ?>
                    <div class="col col-8"></div>
                <?php } ?>

                <?php if ($this ->pp ->idFotografie) { ?>
                    <div class="col col-1 d-xs-none formFotoContainer">
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    </div>
                <?php } ?>
            </div>


            <!-- obdobi + vyber zakazky a casove slozky -->
            <div class="row">
                <div class='col col-3 caption required'><?= StringUtils::htmlTextConvert($this ->obdobi ->popis) ?></div>

                <!-- vyber rozdeleni i v readonly, aby mohl uzivatel zvyraznit vybrane rozdeleni -->
                <div class="col col-2 caption"><?= StringUtils::htmlTextConvert($this ->typRozdeleni ->popis) ?></div>
                <div class="col col-2"><?php $this ->zobrazVyberRozdeleniVysledku($this ->vybraneRozdeleni, true, false); ?></div>
                <div class="col col-4"><?php $this ->zobrazVyberRozdeleniVysledku($this ->vybraneRozdeleni, false, false); ?></div>
            </div>
            <div class="row">
                <div class="col col-5"></div>
                <div class="col col-6">
                    <?php
                        if (!$this ->readOnly) {
                            $this ->zobrazCasoveSlozkyVysledku();
                        }
                    ?>
                    &nbsp;
                </div>
            </div>
        </div>

        <div class="buttons">
            <div class="row">
                <div class="col col-5">
                    <span id="rozdeleni_dv_zpet"><a href="?menuid=zpracovanadochazka&osoba=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this -> obdobi -> zacatek) ?>"><?= TextManager::_('Zpet') ?></a></span>
                </div>

                <!-- tlacitka -->
                <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" />

                <div class="col-4">
                    <?php if ($this ->readOnly) { ?>
                        <input class='button' type='submit' name='stornoDV' value='<?= TextManager::_('Zavrit') ?>' />
                    <?php } else { ?>
                        <input type="submit" class="button" name="zapsatDV" value='<?= TextManager::_('Zapsat') ?>' onclick="ron.showWorkingInfo(); return true;"/>
                        <input type="submit" class="button"
                               data-ron-confirm-text="<?= StringUtils::htmlTextConvert(TextManager::_('Opravdu_vymazat_rozdeleni_dv')) ?>"
                               name='vymazatDV' value='<?= TextManager::_('Vymazat_rozdeleni_dv') ?>' />
                    <?php } ?>
                </div>

                <div class="col-3 align-right">
                    <?php if (!$this ->readOnly  &&  Prava::jsouNejakePrava('schval_rozdeleni_dv')) { ?>
                        <input type="button" id="rozdeleni_dv_schvalit" class="button" <?= $this ->vybraneRozdeleni ? '' : 'disabled="disabled"' ?> value="<?= TextManager::_('Schvalit_rozdeleni') ?>" />
                    <?php } ?>
                </div>
            </div>

        </div>
    </div>


    <?php MessageManager::getInstance() ->showMessages(); ?>

    <table class="browser grid keyInputMove rozdeleniDV">
        <thead>
            <tr>

                <!-- schvaleni - zobrazuje se jen kdyz je schvaleno -->
                <?php if ($this ->schvaleni ->schvaleni1) { ?> <th class='schvaleni'></th> <?php } ?>
                <?php if ($this ->schvaleni ->schvaleni2) { ?> <th class='schvaleni'></th> <?php } ?>
                <?php if ($this ->schvaleni ->schvaleni3) { ?> <th class='schvaleni'></th> <?php } ?>

                <th><?= TextManager::_('Datum') ?></th>
                <th class='rozdeleniDVSloupecRozdeleni'><?= $this ->typRozdeleni ->popis ?></th>

                <?php if (!$this ->readOnly) { ?> <th class="align-center"><?= TextManager::_('Pridat_rozdeleni') ?></th> <?php } ?>

                <th class='align-center'><?= TextManager::_('Celkem_rozdeleno') ?></th>
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?> <th class='align-center'><?= TextManager::_('Celkem_rozdelit') ?></th> <?php } ?>
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?> <th class="align-center"><?= TextManager::_('Zbyva_roz') ?></th> <?php } ?>

                <th class="align-center glyph-col"><!-- schvaleni --></th>

                <?php if ($this ->casovaSlozka2) { ?>
                    <th class="align-center"><?= $this ->nadpisCS2 ?></th>
                    <th class="align-center"><?= $this ->nadpisCS2Celkem ?></th>
                <?php } ?>
            </tr>
        </thead>

        <tbody>
            <?php foreach ($this ->dataList as $index => $den) {

                $cssstyle = Kalendar::getStyleForDate($this ->database, $den ->datum, true, $this ->kalendar);
                $class_str = $cssstyle ? "class='$cssstyle'" : '';
            ?>

            <tr <?= $class_str ?> data-ron-datum="<?= StringUtils::jsonDate($den ->datum) ?>" data-ron-index="<?= $index ?>">

                <!-- schvaleni -->
                <?php if ($this ->schvaleni ->schvaleni1) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni1 >= $den ->datum) ? ' schvaleni1' : '' ?>">
                <?php } ?>

                <?php if ($this ->schvaleni ->schvaleni2) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni2 >= $den ->datum) ? ' schvaleni2' : '' ?>">
                <?php } ?>

                <?php if ($this ->schvaleni ->schvaleni3) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni3 >= $den ->datum) ? ' schvaleni3' : '' ?>">
                <?php } ?>

                <!-- datum -->
                <td class="browser_rowheader">
                    <a href="?menuid=editacedne&idpp=<?= $this ->pp ->idPP ?>&datum=<?=  $den ->datum ?>">
                        <span class="zkratkadne"><?= TextManager::_('Day_short_' . date('w', $den ->datum)) ?></span><?= date('j.n.Y', $den ->datum) ?>
                    </a>
                </td>

                <!-- seznam zaznamu rozdeleni -->
                <td><?php
                    $prvni = true;
                    foreach ($den ->zaznamy as $item) {
                        echo $this ->getItemText($item);
                    }
                ?>
                </td>

                <!-- input -->
                <?php if (!$this ->readOnly) { ?>
                    <td class='align-center'>
                        <?php if ($this ->schvaleni ->lzeEditovatPP($this ->pp ->idPP, $den ->datum)) {
                            $stylestr = ($den->datum < $this->editovatDatumOd || $den->datum > $this->editovatDatumDo) ? "style='display:none'" : '';
                            ?>
                            <input type='text' size='5' class='inputTime <?= MessageManager::getClass('rozdelenidv_' . $index) ?>' name='rozdelenidv_<?= $index ?>' id='rozdelenidv_<?= $index ?>' value='<?= StringUtils::htmlTextConvert($den->hodnotaStr) ?>' <?= $stylestr ?> />
                        <?php } else { ?>
                            <span id='rozdelenidv_<?= $index ?>'></span> <!-- kvuli javascriptum - aby fungovaly, i kdyz je mesic castecne schvaleny -->
                        <?php } ?>
                    </td>
                <?php } ?>

                <!-- soucet -->
                <td class="align-center"><?php if ($den ->soucet) echo StringUtils::format('minuty', round($den ->soucet * 60)); ?></td>

                <!-- celkem -->
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?>
                    <td class="align-center"><?php if ($den ->odpracovano) echo StringUtils::format('minuty', round($den ->odpracovano * 60)); ?></td>
                <?php } ?>

                <!-- zbyva -->
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?>
                    <td class="align-center"><?= $den ->zbyvaStr ?></td>
                <?php } ?>

                <td class="align-center glyph-col"><span class="rozdeleniDVLock fa inline-glyph glyph-lock"></span></td>

                <?php if ($this ->casovaSlozka2) { ?>
                    <td class="align-center">
                        <?php if ($this ->lzeEditovatRozdeleni2($den ->datum)) { ?>
                            <input type='text' size='5' class='inputTime d-none rozdelenidv2 <?= MessageManager::getClass('rozdelenidv2_' . $index) ?>' name='rozdelenidv2_<?= $index ?>' id='rozdelenidv2_<?= $index ?>' value='<?= $den ->hodnotaRozdeleni2Str ?>' />
                        <?php } else { ?>
                            <span id='rozdelenidv2_<?= $index ?>'></span>
                        <?php } ?>
                    </td>
                    <td class="align-center">
                        <?php if ($den ->celkemCasovaSlozka2) echo StringUtils::format('minuty', round($den ->celkemCasovaSlozka2 * 60)); ?>
                    </td>
                <?php } ?>
            </tr>
            <?php } ?>
        </tbody>
    </table>

</form>

<?php
    if (RonPortalSettings::getPouzivatRozdeleniDV() && RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) {
        /** @noinspection PhpUnusedLocalVariableInspection */
        $typrozdeleni = $this ->typRozdeleni;

        require('view/rozdeleniosoby.php');
    ?>
<?php } ?>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/view_rozdeleni_dv_v1.php <==
<?php
/**
 * stanislav.elbl, 27.02.2015
 * Stary zpusob rozdeleni dennich vysledku
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Kalendar;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;

/**
 * @var HromadneRozdeleniDVFormular $this
 */

$datumodstr = isset($_POST['rozdelenidv_datumod']) ? $_POST['rozdelenidv_datumod'] : date('j.n.Y', $this ->editovatDatumOd);
$datumdostr = isset($_POST['rozdelenidv_datumdo']) ? $_POST['rozdelenidv_datumdo'] : date('j.n.Y', $this ->editovatDatumDo);

?>

<h1><?= TextManager::_('Rozdeleni_dennich_vysledku') ?></h1>

<form method="POST" name="rozdeleniDVform" action="?menuid=rozdelenidv&idpp=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>">
    <input type="hidden" name="ulozitRozdeleniDV" value="1" />
    <input type="hidden" name="osoba" value="<?= $this ->pp ->idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>" />


    <!-- hlavicka -->
    <div class="form large-form filtrRozdeleniDV">
        <div class="form-content">
            <!-- osoba a filtr datum od-do -->
            <div class="row">
                <div class="col col-3 caption required"><?= StringUtils::htmlTextConvert($this ->pp ->jmeno . ' ' . $this ->pp ->prijmeni) ?></div>

                <?php if (!$this ->readOnly) { ?>

                    <div class="col col-2 caption"><?= TextManager::_('Datum_od') ?></div>
                    <div class="col col-6">
                        <input id="rozdeleniDV_DatumOd" type='text' size='10' maxlength='10' name='rozdelenidv_datumod' value='<?= StringUtils::htmlTextConvert($datumodstr) ?>'
                               data-roncalendar-mindate="<?= date('j.n.Y', $this ->obdobi ->zacatek) ?>" data-roncalendar-maxdate="<?= date('j.n.Y', $this ->obdobi ->konec) ?>"
                               data-roncalendar-next="rozdelenidv_datumdo" />
                        <i class="showcalendar inline-glyph fa glyph-calendar"  data-roncalendar-inputname="rozdelenidv_datumod"></i>

                        &nbsp;&nbsp;&nbsp;<?= TextManager::_('Do') ?>

                        <input id="rozdeleniDV_DatumDo" type='text' size='10' maxlength='10' name='rozdelenidv_datumdo' value='<?= StringUtils::htmlTextConvert($datumdostr) ?>'
                               data-roncalendar-mindate="<?= date('j.n.Y', $this ->obdobi ->zacatek) ?>" data-roncalendar-maxdate="<?= date('j.n.Y', $this ->obdobi ->konec) ?>"
                               data-roncalendar-prev="rozdelenidv_datumod" />
                        <i class="showcalendar inline-glyph fa glyph-calendar"  data-roncalendar-inputname="rozdelenidv_datumdo"></i>

                        <?php if (RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) { ?>
                            <span class="js float-right" onclick="ronPortal.rozdeleniOsoby_DVHromadne(<?= $this ->pp ->idPP ?>)"><?= TextManager::_('Vybrat_rozdeleni') ?></span>
                        <?php } ?>

                    </div>
                <?php } else { ?>
                    <div class="col col-8"></div>
                <?php } ?>

                <?php if ($this ->pp ->idFotografie) { ?>
                    <div class="col col-1 d-xs-none formFotoContainer">
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    </div>
                <?php } ?>
            </div>


            <!-- obdobi + vyber zakazky a casove slozky -->
            <div class="row">
                <div class='col col-3 caption required'><?= StringUtils::htmlTextConvert($this ->obdobi ->popis) ?></div>

                <!-- vyber rozdeleni i v readonly, aby mohl uzivatel zvyraznit vybrane rozdeleni -->
                <div class="col col-2 caption"><?= StringUtils::htmlTextConvert($this ->typRozdeleni ->popis) ?></div>
                <div class="col col-2"><?php $this ->zobrazVyberRozdeleniVysledku($this ->vybraneRozdeleni, true, false); ?></div>
                <div class="col col-4"><?php $this ->zobrazVyberRozdeleniVysledku($this ->vybraneRozdeleni, false, false); ?></div>
            </div>
            <div class="row">
                <div class="col col-5"></div>
                <div class="col col-6">
                    <?php
                        if (!$this ->readOnly) {
                            $this ->zobrazCasoveSlozkyVysledku();
                        }
                    ?>
                    &nbsp;
                </div>
            </div>
        </div>

        <div class="buttons">
            <div class="row">
                <div class="col col-5">
                    <span id="rozdeleni_dv_zpet"><a href="?menuid=zpracovanadochazka&osoba=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this -> obdobi -> zacatek) ?>"><?= TextManager::_('Zpet') ?></a></span>
                </div>

                <!-- tlacitka -->
                <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" />

                <div class="col-4">
                    <?php if ($this ->readOnly) { ?>
                        <input class='button' type='submit' name='stornoDV' value='<?= TextManager::_('Zavrit') ?>' />
                    <?php } else { ?>
                        <input type="submit" class="button" name="zapsatDV" value='<?= TextManager::_('Zapsat') ?>' onclick="ron.showWorkingInfo(); return true;"/>
                        <input type="submit" class="button"
                               data-ron-confirm-text="<?= StringUtils::htmlTextConvert(TextManager::_('Opravdu_vymazat_rozdeleni_dv')) ?>"
                               name='vymazatDV' value='<?= TextManager::_('Vymazat_rozdeleni_dv') ?>' />
                    <?php } ?>
                </div>

                <div class="col-3 align-right">
                    <?php if (!$this ->readOnly  &&  Prava::jsouNejakePrava('schval_rozdeleni_dv')) { ?>
                        <input type="button" id="rozdeleni_dv_schvalit" class="button" <?= $this ->vybraneRozdeleni ? '' : 'disabled="disabled"' ?> value="<?= TextManager::_('Schvalit_rozdeleni') ?>" />
                    <?php } ?>
                </div>
            </div>

        </div>
    </div>


    <?php MessageManager::getInstance() ->showMessages(); ?>

    <table class="browser grid keyInputMove rozdeleniDV">
        <thead>
            <tr>

                <!-- schvaleni - zobrazuje se jen kdyz je schvaleno -->
                <?php if ($this ->schvaleni ->schvaleni1) { ?> <th class='schvaleni'></th> <?php } ?>
                <?php if ($this ->schvaleni ->schvaleni2) { ?> <th class='schvaleni'></th> <?php } ?>
                <?php if ($this ->schvaleni ->schvaleni3) { ?> <th class='schvaleni'></th> <?php } ?>

                <th><?= TextManager::_('Datum') ?></th>
                <th class='rozdeleniDVSloupecRozdeleni'><?= $this ->typRozdeleni ->popis ?></th>

                <?php if (!$this ->readOnly) { ?> <th class="align-center"><?= TextManager::_('Pridat_rozdeleni') ?></th> <?php } ?>

                <th class='align-center'><?= TextManager::_('Celkem_rozdeleno') ?></th>
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?> <th class='align-center'><?= TextManager::_('Celkem_rozdelit') ?></th> <?php } ?>
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?> <th class="align-center"><?= TextManager::_('Zbyva_roz') ?></th> <?php } ?>

                <th class="align-center glyph-col"><!-- schvaleni --></th>

                <?php if ($this ->casovaSlozka2) { ?>
                    <th class="align-center"><?= $this ->nadpisCS2 ?></th>
                    <th class="align-center"><?= $this ->nadpisCS2Celkem ?></th>
                <?php } ?>
            </tr>
        </thead>

        <tbody>
            <?php foreach ($this ->dataList as $index => $den) {

                $cssstyle = Kalendar::getStyleForDate($this ->database, $den ->datum, true, $this ->kalendar);
                $class_str = $cssstyle ? "class='$cssstyle'" : '';
            ?>

            <tr <?= $class_str ?> data-ron-datum="<?= StringUtils::jsonDate($den ->datum) ?>" data-ron-index="<?= $index ?>">

                <!-- schvaleni -->
                <?php if ($this ->schvaleni ->schvaleni1) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni1 >= $den ->datum) ? ' schvaleni1' : '' ?>">
                <?php } ?>

                <?php if ($this ->schvaleni ->schvaleni2) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni2 >= $den ->datum) ? ' schvaleni2' : '' ?>">
                <?php } ?>

                <?php if ($this ->schvaleni ->schvaleni3) { ?>
                    <td class="schvaleni<?= ($this->schvaleni->schvaleni3 >= $den ->datum) ? ' schvaleni3' : '' ?>">
                <?php } ?>

                <!-- datum -->
                <td class="browser_rowheader">
                    <a href="?menuid=editacedne&idpp=<?= $this ->pp ->idPP ?>&datum=<?=  $den ->datum ?>">
                        <span class="zkratkadne"><?= TextManager::_('Day_short_' . date('w', $den ->datum)) ?></span><?= date('j.n.Y', $den ->datum) ?>
                    </a>
                </td>

                <!-- seznam zaznamu rozdeleni -->
                <td><?php
                    $prvni = true;
                    foreach ($den ->zaznamy as $item) {
                        echo $this ->getItemText($item);
                    }
                ?>
                </td>

                <!-- input -->
                <?php if (!$this ->readOnly) { ?>
                    <td class='align-center'>
                        <?php if ($this ->schvaleni ->lzeEditovatPP($this ->pp ->idPP, $den ->datum)) {
                            $stylestr = ($den->datum < $this->editovatDatumOd || $den->datum > $this->editovatDatumDo) ? "style='display:none'" : '';
                            ?>
                            <input type='text' size='5' class='inputTime <?= MessageManager::getClass('rozdelenidv_' . $index) ?>' name='rozdelenidv_<?= $index ?>' id='rozdelenidv_<?= $index ?>' value='<?= StringUtils::htmlTextConvert($den->hodnotaStr) ?>' <?= $stylestr ?> />
                        <?php } else { ?>
                            <span id='rozdelenidv_<?= $index ?>'></span> <!-- kvuli javascriptum - aby fungovaly, i kdyz je mesic castecne schvaleny -->
                        <?php } ?>
                    </td>
                <?php } ?>

                <!-- soucet -->
                <td class="align-center"><?php if ($den ->soucet) echo StringUtils::format('minuty', round($den ->soucet * 60)); ?></td>

                <!-- celkem -->
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?>
                    <td class="align-center"><?php if ($den ->odpracovano) echo StringUtils::format('minuty', round($den ->odpracovano * 60)); ?></td>
                <?php } ?>

                <!-- zbyva -->
                <?php if (RonPortalSettings::getValue(RonPortalSettings::DV_CASOVA_SLOZKA_SOUCET)) { ?>
                    <td class="align-center"><?= $den ->zbyvaStr ?></td>
                <?php } ?>

                <td class="align-center glyph-col"><span class="rozdeleniDVLock fa inline-glyph glyph-lock"></span></td>

                <?php if ($this ->casovaSlozka2) { ?>
                    <td class="align-center">
                        <?php if ($this ->lzeEditovatRozdeleni2($den ->datum)) { ?>
                            <input type='text' size='5' class='inputTime d-none rozdelenidv2 <?= MessageManager::getClass('rozdelenidv2_' . $index) ?>' name='rozdelenidv2_<?= $index ?>' id='rozdelenidv2_<?= $index ?>' value='<?= $den ->hodnotaRozdeleni2Str ?>' />
                        <?php } else { ?>
                            <span id='rozdelenidv2_<?= $index ?>'></span>
                        <?php } ?>
                    </td>
                    <td class="align-center">
                        <?php if ($den ->celkemCasovaSlozka2) echo StringUtils::format('minuty', round($den ->celkemCasovaSlozka2 * 60)); ?>
                    </td>
                <?php } ?>
            </tr>
            <?php } ?>
        </tbody>
    </table>

</form>

<?php
    if (RonPortalSettings::getPouzivatRozdeleniDV() && RonPortalSettings::getIntValue(RonPortalSettings::DV_POVOLIT_PRIRAZENI_ROZDELENI)) {
        /** @noinspection PhpUnusedLocalVariableInspection  Pouzito ve view */
        $typrozdeleni = $this ->typRozdeleni;
        /** @noinspection PhpUnusedLocalVariableInspection  Pouzito ve view */
        $url = '?menuid=editace&action=rozdeleniosoby&idpp=' . $this ->pp ->idPP;

        require('view/rozdeleniosoby.php');
    ?>
<?php } ?>
